@@ -59,6 +59,9 @@ politenessPlot<-function(df_polite,
   if(is.factor(split)){
     split<-as.character(split)
   }
+  if(is.list(split)){
+    split<-unlist(split)
+  }
   # confirm that split only has two values
   if( length(unique(split)) != 2){
     if(is.character(split)){
