@@ -24,18 +24,22 @@ utils::globalVariables(c("receptive_train")) # prevent incorrect "no global bind
 #'
 #'@export
 receptiveness<-function(texts, num_mc_cores=1){
-  m_polite_train = as.matrix(politeness::politeness(politeness::receptive_train$text,
-                                                    parser="spacy",
-                                                    num_mc_cores=num_mc_cores))
+  train_dat=politeness::receptive_train
+
+  m_polite_train = as.matrix(politeness::receptive_polite)
 
   m_polite_test = as.matrix(politeness::politeness(texts,
                                                    parser="spacy",
                                                    num_mc_cores=num_mc_cores))
 
-  polite_predict<-as.vector(politeness::politenessProjection(m_polite_train,
-                                                             politeness::receptive_train$receptive,
-                                                             m_polite_test)$test_proj)
+  # Remove 1st/2nd person pronouns
+  m_train=m_polite_train[,-which(colnames(m_polite_train)%in%c("First.Person.Single","Second.Person"))]
+  m_test=m_polite_test[,-which(colnames(m_polite_test)%in%c("First.Person.Single","Second.Person")),drop=FALSE]
+
+  recept_predict<-as.vector(politeness::politenessProjection(m_train,
+                                                             train_dat$receptive,
+                                                             m_test)$test_proj)
 
 
-  return(polite_predict)
+  return(recept_predict)
 }
