@@ -84,7 +84,7 @@ usWords<-function(text){
   toks <- quanteda::tokens(text)
   tokUS<-quanteda::tokens_lookup(toks, politeness::uk2us,
                                  exclusive = FALSE,capkeys = FALSE)
-  sentUS<-unlist(lapply(tokUS,paste, collapse=" "),use.names = F)
+  sentUS<-unlist(lapply(tokUS,paste, collapse=" "),use.names = FALSE)
   return(sentUS)
 }
 
@@ -99,12 +99,10 @@ cleanpunct<-function(text){
   # text<-gsub("“", '"', text)
   # text<-gsub("”", '"', text)
   #text<-gsub(",Äô", '\'', text,fixed=T)
-  text<-gsub(",", ", ", text,fixed=T)
-  text<-gsub(".", ". ", text,fixed=T)
-  text<-gsub(". .", "..", text,fixed=T)
-  text<-gsub("[\x84\x93\x94]", '"', text)
+  text<-gsub(",", ", ", text,fixed=TRUE, useBytes = TRUE)
+  text<-gsub(".", ". ", text,fixed=TRUE)
+  text<-gsub(". .", "..", text,fixed=TRUE)
   text<-gsub("[\u201C\u201D\u201E\u201F\u2033\u2036]", '"', text)
-  text<-gsub("[\x82\x91\x92]", "'", text)
   text<-gsub("[\u2018\u2019\u201A\u201B\u2032\u2035]", "'", text)
   text<-stringi::stri_trans_general(text, "latin-ascii")
   return(text)
